@@ -67,7 +67,7 @@ CONF.register_opts(opts, group='disk_utils')
 LOG = logging.getLogger(__name__)
 
 _PARTED_PRINT_RE = re.compile(r"^(\d+):([\d\.]+)MiB:"
-                              "([\d\.]+)MiB:([\d\.]+)MiB:(\w*):(.*):(.*);")
+                              "([\d\.]+)MiB:([\d\.]+)MiB:(\w*)::(\w*)")
 
 CONFIGDRIVE_LABEL = "config-2"
 MAX_CONFIG_DRIVE_SIZE_MB = 64
@@ -84,8 +84,7 @@ def list_partitions(device):
 
     :param device: The device path.
     :returns: list of dictionaries (one per partition) with keys:
-              number, start, end, size (in MiB), filesystem, partition_name,
-              flags
+              number, start, end, size (in MiB), filesystem, flags
     """
     output = utils.execute(
         'parted', '-s', '-m', device, 'unit', 'MiB', 'print',
@@ -94,8 +93,7 @@ def list_partitions(device):
         output = output.decode("utf-8")
     lines = [line for line in output.split('\n') if line.strip()][2:]
     # Example of line: 1:1.00MiB:501MiB:500MiB:ext4::boot
-    fields = ('number', 'start', 'end', 'size', 'filesystem', 'partition_name',
-              'flags')
+    fields = ('number', 'start', 'end', 'size', 'filesystem', 'flags')
     result = []
     for line in lines:
         match = _PARTED_PRINT_RE.match(line)
@@ -297,7 +295,8 @@ def is_block_device(dev):
 
 def dd(src, dst):
     """Execute dd from src to dst."""
-    utils.dd(src, dst, 'bs=%s' % CONF.disk_utils.dd_block_size, 'oflag=direct')
+    utils.dd(src, dst, 'bs=%s' % CONF.disk_utils.dd_block_size, 'oflag=direct',
+             'conv=sparse')
 
 
 def qemu_img_info(path):
@@ -655,7 +654,7 @@ def _get_labelled_partition(device_path, label, node_uuid):
                    for v in shlex.split(device))}
             if not dev:
                 continue
-            if dev['LABEL'].upper() == label.upper():
+            if dev['LABEL'] == label:
                 if found_part:
                     found_2 = '/dev/%(part)s' % {'part': dev['NAME'].strip()}
                     found = [found_part, found_2]
@@ -704,10 +703,12 @@ def _fix_gpt_structs(device, node_uuid):
         commands fail.
     """
     try:
-        output, _err = utils.execute('sgdisk', '-v', device, run_as_root=True)
+        output, err = utils.execute('partprobe', device,
+                                    use_standard_locale=True,
+                                    run_as_root=True)
 
-        search_str = "it doesn't reside\nat the end of the disk"
-        if search_str in output:
+        search_str = "fix the GPT to use all of the space"
+        if search_str in err:
             utils.execute('sgdisk', '-e', device, run_as_root=True)
     except (processutils.UnknownArgumentError,
             processutils.ProcessExecutionError, OSError) as e:
@@ -718,28 +719,6 @@ def _fix_gpt_structs(device, node_uuid):
         raise exception.InstanceDeployFailure(msg)
 
 
-def _fix_gpt_partition(device, node_uuid):
-    """Fix GPT partition
-
-    Fix GPT table information when image is written to a disk which
-    has a bigger extend (e.g. 30GB image written on a 60Gb physical disk).
-
-    :param device: The device path.
-    :param node_uuid: UUID of the Node.
-    :raises: InstanceDeployFailure if exception is caught.
-    """
-    try:
-        disk_is_gpt_partitioned = _is_disk_gpt_partitioned(device, node_uuid)
-        if disk_is_gpt_partitioned:
-            _fix_gpt_structs(device, node_uuid)
-    except Exception as e:
-        msg = (_('Failed to fix GPT partition on disk %(disk)s '
-                 'for node %(node)s. Error: %(error)s') %
-               {'disk': device, 'node': node_uuid, 'error': e})
-        LOG.error(msg)
-        raise exception.InstanceDeployFailure(msg)
-
-
 def create_config_drive_partition(node_uuid, device, configdrive):
     """Create a partition for config drive
 
@@ -772,7 +751,6 @@ def create_config_drive_partition(node_uuid, device, configdrive):
                   "device: %(dev)s for node %(node)s",
                   {'dev': device, 'size': confdrive_mb, 'node': node_uuid})
 
-        _fix_gpt_partition(device, node_uuid)
         if config_drive_part:
             LOG.debug("Configdrive for node %(node)s exists at "
                       "%(part)s",
@@ -781,6 +759,7 @@ def create_config_drive_partition(node_uuid, device, configdrive):
             cur_parts = set(part['number'] for part in list_partitions(device))
 
             if _is_disk_gpt_partitioned(device, node_uuid):
+                _fix_gpt_structs(device, node_uuid)
                 create_option = '0:-%dMB:0' % MAX_CONFIG_DRIVE_SIZE_MB
                 utils.execute('sgdisk', '-n', create_option, device,
                               run_as_root=True)
@@ -822,25 +801,6 @@ def create_config_drive_partition(node_uuid, device, configdrive):
                 utils.execute('parted', '-a', 'optimal', '-s', '--', device,
                               'mkpart', 'primary', 'fat32', startlimit,
                               endlimit, run_as_root=True)
-            # Parted uses fsync to tell the kernel to sync file io
-            # however on ramdisks in ramfs, this is an explicit no-op.
-            # Explicitly call sync so when the the kernel attempts to read
-            # the partition table from disk, it is less likely that the write
-            # is still in buffer cache pending write to disk.
-            LOG.debug('Explicitly calling sync to force buffer/cache flush.')
-            utils.execute('sync')
-            # Make sure any additions to the partitioning are reflected in the
-            # kernel.
-            LOG.debug('Waiting until udev event queue is empty')
-            utils.execute('udevadm', 'settle')
-            try:
-                utils.execute('partprobe', device, run_as_root=True,
-                              attempts=CONF.disk_utils.partprobe_attempts)
-                # Also verify that the partitioning is correct now.
-                utils.execute('sgdisk', '-v', device, run_as_root=True)
-            except processutils.ProcessExecutionError as exc:
-                LOG.warning('Failed to verify GPT partitioning after creating '
-                            'the configdrive partition: %s', exc)
 
             upd_parts = set(part['number'] for part in list_partitions(device))
             new_part = set(upd_parts) - set(cur_parts)
