@@ -47,9 +47,9 @@ BYT;
 """
         expected = [
             {'number': 1, 'start': 1, 'end': 501, 'size': 500,
-             'filesystem': 'ext4', 'partition_name': '', 'flags': 'boot'},
+             'filesystem': 'ext4', 'flags': 'boot'},
             {'number': 2, 'start': 501, 'end': 476940, 'size': 476439,
-             'filesystem': '', 'partition_name': '', 'flags': ''},
+             'filesystem': '', 'flags': ''},
         ]
         execute_mock.return_value = (output, '')
         result = disk_utils.list_partitions('/dev/fake')
@@ -70,46 +70,6 @@ BYT;
         self.assertEqual(1, log_mock.call_count)
 
 
-@mock.patch.object(utils, 'execute', autospec=True)
-class ListPartitionsGPTTestCase(base.IronicLibTestCase):
-
-    def test_correct(self, execute_mock):
-        output = """
-BYT;
-/dev/vda:40960MiB:virtblk:512:512:gpt:Virtio Block Device:;
-2:1.00MiB:2.00MiB:1.00MiB::Bios partition:bios_grub;
-1:4.00MiB:5407MiB:5403MiB:ext4:Root partition:;
-3:5407MiB:5507MiB:100MiB:fat16:Boot partition:boot, esp;
-"""
-        expected = [
-            {'end': 2, 'number': 2, 'start': 1, 'flags': 'bios_grub',
-             'filesystem': '', 'partition_name': 'Bios partition', 'size': 1},
-            {'end': 5407, 'number': 1, 'start': 4, 'flags': '',
-             'filesystem': 'ext4', 'partition_name': 'Root partition',
-             'size': 5403},
-            {'end': 5507, 'number': 3, 'start': 5407,
-             'flags': 'boot, esp', 'filesystem': 'fat16',
-             'partition_name': 'Boot partition', 'size': 100},
-        ]
-        execute_mock.return_value = (output, '')
-        result = disk_utils.list_partitions('/dev/fake')
-        self.assertEqual(expected, result)
-        execute_mock.assert_called_once_with(
-            'parted', '-s', '-m', '/dev/fake', 'unit', 'MiB', 'print',
-            use_standard_locale=True, run_as_root=True)
-
-    @mock.patch.object(disk_utils.LOG, 'warning', autospec=True)
-    def test_incorrect(self, log_mock, execute_mock):
-        output = """
-BYT;
-/dev/vda:40960MiB:virtblk:512:512:gpt:Virtio Block Device:;
-2:XX1.00MiB:---:1.00MiB::primary:bios_grub;
-"""
-        execute_mock.return_value = (output, '')
-        self.assertEqual([], disk_utils.list_partitions('/dev/fake'))
-        self.assertEqual(1, log_mock.call_count)
-
-
 @mock.patch.object(disk_partitioner.DiskPartitioner, 'commit', lambda _: None)
 class WorkOnDiskTestCase(base.IronicLibTestCase):
 
@@ -399,14 +359,7 @@ class MakePartitionsTestCase(base.IronicLibTestCase):
         fuser_cmd = ['fuser', 'fake-dev']
         fuser_call = mock.call(*fuser_cmd, run_as_root=True,
                                check_exit_code=[0, 1])
-
-        sync_calls = [mock.call('sync'),
-                      mock.call('udevadm', 'settle'),
-                      mock.call('partprobe', self.dev, attempts=10,
-                                run_as_root=True),
-                      mock.call('sgdisk', '-v', self.dev, run_as_root=True)]
-
-        mock_exc.assert_has_calls([parted_call, fuser_call] + sync_calls)
+        mock_exc.assert_has_calls([parted_call, fuser_call])
 
     def test_make_partitions(self, mock_exc):
         self._test_make_partitions(mock_exc, boot_option="netboot")
@@ -511,7 +464,7 @@ class MakePartitionsTestCase(base.IronicLibTestCase):
         self.assertEqual(expected_result, result)
 
 
-@mock.patch.object(utils, 'execute', autospec=True)
+@mock.patch.object(utils, 'execute', autospec=True, return_value=('', ''))
 class DestroyMetaDataTestCase(base.IronicLibTestCase):
 
     def setUp(self):
@@ -520,31 +473,9 @@ class DestroyMetaDataTestCase(base.IronicLibTestCase):
         self.node_uuid = "12345678-1234-1234-1234-1234567890abcxyz"
 
     def test_destroy_disk_metadata(self, mock_exec):
-        # Note(TheJulia): This list will get-reused, but only the second
-        # execution returning a string is needed for the test as otherwise
-        # command output is not used.
-        mock_exec.side_effect = iter([
-            (None, None),
-            ('1024\n', None),
-            (None, None),
-            (None, None),
-            (None, None),
-            (None, None)])
-
         expected_calls = [mock.call('wipefs', '--force', '--all', 'fake-dev',
                                     run_as_root=True,
                                     use_standard_locale=True),
-                          mock.call('blockdev', '--getsz', 'fake-dev',
-                                    check_exit_code=[0],
-                                    run_as_root=True),
-                          mock.call('dd', 'bs=512', 'if=/dev/zero',
-                                    'of=fake-dev', 'count=33',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
-                          mock.call('dd', 'bs=512', 'if=/dev/zero',
-                                    'of=fake-dev', 'count=33', 'seek=991',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
                           mock.call('sgdisk', '-Z', 'fake-dev',
                                     run_as_root=True,
                                     use_standard_locale=True),
@@ -570,26 +501,11 @@ class DestroyMetaDataTestCase(base.IronicLibTestCase):
         expected_calls = [mock.call('wipefs', '--force', '--all', 'fake-dev',
                                     run_as_root=True,
                                     use_standard_locale=True),
-                          mock.call('blockdev', '--getsz', 'fake-dev',
-                                    check_exit_code=[0],
-                                    run_as_root=True),
-                          mock.call('dd', 'bs=512', 'if=/dev/zero',
-                                    'of=fake-dev', 'count=33',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
-                          mock.call('dd', 'bs=512', 'if=/dev/zero',
-                                    'of=fake-dev', 'count=33', 'seek=991',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
                           mock.call('sgdisk', '-Z', 'fake-dev',
                                     run_as_root=True,
                                     use_standard_locale=True)]
-        mock_exec.side_effect = iter([
-            (None, None),
-            ('1024\n', None),
-            (None, None),
-            (None, None),
-            processutils.ProcessExecutionError()])
+        mock_exec.side_effect = [(None, None),
+                                 processutils.ProcessExecutionError()]
         self.assertRaises(processutils.ProcessExecutionError,
                           disk_utils.destroy_disk_metadata,
                           self.dev,
@@ -597,14 +513,11 @@ class DestroyMetaDataTestCase(base.IronicLibTestCase):
         mock_exec.assert_has_calls(expected_calls)
 
     def test_destroy_disk_metadata_wipefs_not_support_force(self, mock_exec):
-        mock_exec.side_effect = iter([
-            processutils.ProcessExecutionError(description='--force'),
-            (None, None),
-            ('1024\n', None),
-            (None, None),
-            (None, None),
-            (None, None),
-            (None, None)])
+        mock_exec.side_effect = iter(
+            [processutils.ProcessExecutionError(description='--force'),
+             (None, None),
+             (None, None),
+             ('', '')])
 
         expected_call = [mock.call('wipefs', '--force', '--all', 'fake-dev',
                                    run_as_root=True,
@@ -652,9 +565,6 @@ class PopulateImageTestCase(base.IronicLibTestCase):
         self.assertFalse(mock_dd.called)
 
 
-# NOTE(TheJulia): _trigger_device_rescan is systemwide thus pointless
-# to execute in the file test case. Also, CI unit test jobs lack sgdisk.
-@mock.patch.object(disk_utils, '_trigger_device_rescan', lambda *_: None)
 @mock.patch.object(utils, 'wait_for_disk_to_become_available', lambda *_: None)
 @mock.patch.object(disk_utils, 'is_block_device', lambda d: True)
 @mock.patch.object(disk_utils, 'block_uuid', lambda p: 'uuid')
@@ -925,22 +835,6 @@ class WholeDiskPartitionTestCases(base.IronicLibTestCase):
         ]
         mock_execute.assert_has_calls(execute_calls)
 
-    def test_get_partition_present_uppercase(self, mock_execute):
-        lsblk_output = 'NAME="fake12" LABEL="CONFIG-2"\n'
-        part_result = '/dev/fake12'
-        mock_execute.side_effect = [(None, ''), (lsblk_output, '')]
-        result = disk_utils._get_labelled_partition(self.dev,
-                                                    self.config_part_label,
-                                                    self.node_uuid)
-        self.assertEqual(part_result, result)
-        execute_calls = [
-            mock.call('partprobe', self.dev, run_as_root=True, attempts=10),
-            mock.call('lsblk', '-Po', 'name,label', self.dev,
-                      check_exit_code=[0, 1],
-                      use_standard_locale=True, run_as_root=True)
-        ]
-        mock_execute.assert_has_calls(execute_calls)
-
     def test_get_partition_absent(self, mock_execute):
         mock_execute.side_effect = [(None, ''),
                                     (None, '')]
@@ -1054,17 +948,18 @@ class WholeDiskPartitionTestCases(base.IronicLibTestCase):
         self.assertEqual(1, mock_log.call_count)
 
     def test_fix_gpt_structs_fix_required(self, mock_execute):
-        sgdisk_v_output = """
-Problem: The secondary header's self-pointer indicates that it doesn't reside
-at the end of the disk. If you've added a disk to a RAID array, use the 'e'
-option on the experts' menu to adjust the secondary header's and partition
-table's locations.
-
-Identified 1 problems!
+        partprobe_err = """
+Error: The backup GPT table is not at the end of the disk, as it should be.
+This might mean that another operating system believes the disk is smaller.
+Fix, by moving the backup to the end (and removing the old backup)?
+Warning: Not all of the space available to /dev/sdb appears to be used,
+you can fix the GPT to use all of the space (an extra 581456476 blocks)
+or continue with the current setting?
 """
-        mock_execute.return_value = (sgdisk_v_output, '')
+        mock_execute.return_value = ('', partprobe_err)
         execute_calls = [
-            mock.call('sgdisk', '-v', '/dev/fake', run_as_root=True),
+            mock.call('partprobe', '/dev/fake', use_standard_locale=True,
+                      run_as_root=True),
             mock.call('sgdisk', '-e', '/dev/fake', run_as_root=True)
         ]
         disk_utils._fix_gpt_structs('/dev/fake', self.node_uuid)
@@ -1074,7 +969,8 @@ Identified 1 problems!
         mock_execute.return_value = ('', '')
 
         disk_utils._fix_gpt_structs('/dev/fake', self.node_uuid)
-        mock_execute.assert_called_once_with('sgdisk', '-v', '/dev/fake',
+        mock_execute.assert_called_once_with('partprobe', '/dev/fake',
+                                             use_standard_locale=True,
                                              run_as_root=True)
 
     @mock.patch.object(disk_utils.LOG, 'error', autospec=True)
@@ -1084,7 +980,8 @@ Identified 1 problems!
                                'Failed to fix GPT data structures on disk',
                                disk_utils._fix_gpt_structs,
                                self.dev, self.node_uuid)
-        mock_execute.assert_called_once_with('sgdisk', '-v', '/dev/fake',
+        mock_execute.assert_called_once_with('partprobe', '/dev/fake',
+                                             use_standard_locale=True,
                                              run_as_root=True)
         self.assertEqual(1, mock_log.call_count)
 
@@ -1102,8 +999,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, 'dd',
                        autospec=True)
-    @mock.patch.object(disk_utils, '_fix_gpt_partition',
-                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1116,8 +1011,8 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     def test_create_partition_exists(self, mock_get_configdrive,
                                      mock_get_labelled_partition,
-                                     mock_list_partitions, mock_is_disk_gpt,
-                                     mock_fix_gpt, mock_fix_gpt_partition,
+                                     mock_list_partitions,
+                                     mock_is_disk_gpt, mock_fix_gpt,
                                      mock_dd, mock_unlink, mock_execute):
         config_url = 'http://1.2.3.4/cd'
         configdrive_part = '/dev/fake-part1'
@@ -1128,15 +1023,13 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
         mock_get_configdrive.return_value = (configdrive_mb, configdrive_file)
         disk_utils.create_config_drive_partition(self.node_uuid, self.dev,
                                                  config_url)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
         mock_get_labelled_partition.assert_called_with(self.dev,
                                                        self.config_part_label,
                                                        self.node_uuid)
         self.assertFalse(mock_list_partitions.called)
-        self.assertFalse(mock_execute.called)
         self.assertFalse(mock_is_disk_gpt.called)
-        self.assertFalse(mock_fix_gpt.called)
+        self.assertFalse(mock_execute.called)
         mock_dd.assert_called_with(configdrive_file, configdrive_part)
         mock_unlink.assert_called_with(configdrive_file)
 
@@ -1145,8 +1038,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, 'dd',
                        autospec=True)
-    @mock.patch.object(disk_utils, '_fix_gpt_partition',
-                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1160,8 +1051,8 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
     def test_create_partition_gpt(self, mock_get_configdrive,
                                   mock_get_labelled_partition,
                                   mock_list_partitions, mock_is_disk_gpt,
-                                  mock_fix_gpt, mock_fix_gpt_partition,
-                                  mock_dd, mock_unlink, mock_execute):
+                                  mock_fix_gpt, mock_dd, mock_unlink,
+                                  mock_execute):
         config_url = 'http://1.2.3.4/cd'
         configdrive_file = '/tmp/xyz'
         configdrive_mb = 10
@@ -1195,11 +1086,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
         mock_execute.assert_has_calls([
             mock.call('sgdisk', '-n', '0:-64MB:0', self.dev,
                       run_as_root=True),
-            mock.call('sync'),
-            mock.call('udevadm', 'settle'),
-            mock.call('partprobe', self.dev, attempts=10, run_as_root=True),
-            mock.call('sgdisk', '-v', self.dev, run_as_root=True),
-
             mock.call('udevadm', 'settle'),
             mock.call('test', '-e', expected_part, attempts=15,
                       check_exit_code=[0], delay_on_retry=True)
@@ -1207,9 +1093,7 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
 
         self.assertEqual(2, mock_list_partitions.call_count)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
-        self.assertFalse(mock_fix_gpt.called)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
+        mock_fix_gpt.assert_called_with(self.dev, self.node_uuid)
         mock_dd.assert_called_with(configdrive_file, expected_part)
         mock_unlink.assert_called_with(configdrive_file)
 
@@ -1222,8 +1106,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_larger_than_max_size',
                        autospec=True)
-    @mock.patch.object(disk_utils, '_fix_gpt_partition',
-                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1238,7 +1120,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                    mock_get_labelled_partition,
                                    mock_list_partitions,
                                    mock_is_disk_gpt, mock_fix_gpt,
-                                   mock_fix_gpt_partition,
                                    mock_disk_exceeds, mock_dd,
                                    mock_unlink, mock_log, mock_execute,
                                    mock_count, disk_size_exceeds_max=False,
@@ -1279,7 +1160,7 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                         self.node_uuid)
             expected_part = '%s-part4' % self.dev
         elif is_nvme_device:
-            self.dev = '/dev/nvmefake0'
+            self.dev = '/dev/nvmefake'
             expected_part = '%sp4' % self.dev
         else:
             expected_part = '/dev/fake4'
@@ -1301,22 +1182,16 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                     '-0', run_as_root=True)
         mock_execute.assert_has_calls([
             parted_call,
-            mock.call('sync'),
-            mock.call('udevadm', 'settle'),
-            mock.call('partprobe', self.dev, attempts=10, run_as_root=True),
-            mock.call('sgdisk', '-v', self.dev, run_as_root=True),
             mock.call('udevadm', 'settle'),
             mock.call('test', '-e', expected_part, attempts=15,
                       check_exit_code=[0], delay_on_retry=True)
         ])
         self.assertEqual(2, mock_list_partitions.call_count)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_disk_exceeds.assert_called_with(self.dev, self.node_uuid)
         mock_dd.assert_called_with(configdrive_file, expected_part)
         mock_unlink.assert_called_with(configdrive_file)
         self.assertFalse(mock_fix_gpt.called)
-        self.assertFalse(mock_fix_gpt.called)
         mock_count.assert_called_with(self.dev)
 
     def test__create_partition_mbr_disk_under_2TB(self):
@@ -1347,8 +1222,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_larger_than_max_size',
                        autospec=True)
-    @mock.patch.object(disk_utils, '_fix_gpt_partition',
-                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1363,7 +1236,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                                mock_get_labelled_partition,
                                                mock_list_partitions,
                                                mock_is_disk_gpt, mock_fix_gpt,
-                                               mock_fix_gpt_partition,
                                                mock_disk_exceeds, mock_dd,
                                                mock_unlink, mock_execute,
                                                mock_count):
@@ -1401,19 +1273,11 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                self.node_uuid, self.dev, config_url)
 
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
-        mock_execute.assert_has_calls([
-            mock.call('parted', '-a', 'optimal', '-s', '--',
-                      self.dev, 'mkpart', 'primary',
-                      'fat32', '-64MiB', '-0',
-                      run_as_root=True),
-            mock.call('sync'),
-            mock.call('udevadm', 'settle'),
-            mock.call('partprobe', self.dev, attempts=10, run_as_root=True),
-            mock.call('sgdisk', '-v', self.dev, run_as_root=True),
-        ])
-
+        mock_execute.assert_called_with('parted', '-a', 'optimal', '-s', '--',
+                                        self.dev, 'mkpart', 'primary',
+                                        'fat32', '-64MiB', '-0',
+                                        run_as_root=True)
         self.assertEqual(2, mock_list_partitions.call_count)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         mock_disk_exceeds.assert_called_with(self.dev, self.node_uuid)
         self.assertFalse(mock_fix_gpt.called)
@@ -1429,8 +1293,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_larger_than_max_size',
                        autospec=True)
-    @mock.patch.object(disk_utils, '_fix_gpt_partition',
-                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1445,7 +1307,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                               mock_get_labelled_partition,
                                               mock_list_partitions,
                                               mock_is_disk_gpt, mock_fix_gpt,
-                                              mock_fix_gpt_partition,
                                               mock_disk_exceeds, mock_dd,
                                               mock_unlink, mock_execute,
                                               mock_count):
@@ -1482,7 +1343,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                         'fat32', '-64MiB', '-0',
                                         run_as_root=True)
         self.assertEqual(1, mock_list_partitions.call_count)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         mock_disk_exceeds.assert_called_with(self.dev, self.node_uuid)
         self.assertFalse(mock_fix_gpt.called)
@@ -1495,8 +1355,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, 'dd',
                        autospec=True)
-    @mock.patch.object(disk_utils, '_fix_gpt_partition',
-                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1511,7 +1369,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                                mock_get_labelled_partition,
                                                mock_list_partitions,
                                                mock_is_disk_gpt, mock_fix_gpt,
-                                               mock_fix_gpt_partition,
                                                mock_dd, mock_unlink,
                                                mock_count):
         config_url = 'http://1.2.3.4/cd'
@@ -1541,7 +1398,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
 
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
         self.assertEqual(1, mock_list_partitions.call_count)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         self.assertFalse(mock_fix_gpt.called)
         self.assertFalse(mock_dd.called)
@@ -1577,8 +1433,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
     @mock.patch.object(utils, 'execute', autospec=True)
     @mock.patch.object(utils, 'unlink_without_raise',
                        autospec=True)
-    @mock.patch.object(disk_utils, '_fix_gpt_partition',
-                       autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
                        autospec=True)
     @mock.patch.object(disk_utils, '_get_labelled_partition',
@@ -1587,8 +1441,7 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                        autospec=True)
     def test_create_partition_conf_drive_error_counting(
             self, mock_get_configdrive, mock_get_labelled_partition,
-            mock_is_disk_gpt, mock_fix_gpt_partition,
-            mock_unlink, mock_execute, mock_count):
+            mock_is_disk_gpt, mock_unlink, mock_execute, mock_count):
         config_url = 'http://1.2.3.4/cd'
         configdrive_file = '/tmp/xyz'
         configdrive_mb = 10
@@ -1605,6 +1458,5 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
 
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
         mock_unlink.assert_called_with(configdrive_file)
-        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         mock_count.assert_called_once_with(self.dev)
